pub enum RawAuditEventKind {
Created,
Updated,
Deleted,
Recovered,
SchemaCreated,
SchemaVerified,
FieldAdded,
DataSeeded,
}Variants
Created
Updated
Deleted
Recovered
SchemaCreated
Emitted when a new table is created during schema bootstrap.
SchemaVerified
Emitted when an existing table is verified during schema bootstrap.
FieldAdded
Emitted when a new column is added to an existing table (schema migration).
DataSeeded
Emitted when initial seed data is inserted or updated during bootstrap.