pub struct ChangeSetStack { /* private fields */ }Implementations
Sourceimpl ChangeSetStack
impl ChangeSetStack
pub fn current_mut(&mut self) -> &mut EntityChangeSet
pub fn current(&self) -> Option<&EntityChangeSet>
pub fn push(&mut self)
pub fn pop(&mut self) -> Option<EntityChangeSet>
pub fn get(&self, key: &EntityKey, field: &str) -> Option<Value>
pub fn set(&mut self, key: EntityKey, field: impl Into<String>, value: Value)
pub fn clear_current(&mut self)
Sourcepub fn clear_entity(&mut self, key: &EntityKey)
pub fn clear_entity(&mut self, key: &EntityKey)
Remove all pending changes for a specific entity key across all stack levels.
Sourcepub fn changed_field_names(&self, key: &EntityKey) -> BTreeSet<String>
pub fn changed_field_names(&self, key: &EntityKey) -> BTreeSet<String>
Get the union of all changed field names for a given entity key across all stack levels.
This is the Rust equivalent of Java’s entity.getUpdatedProperties().