pub struct EntityChangeSet { /* private fields */ }Implementations
Sourceimpl EntityChangeSet
impl EntityChangeSet
pub fn is_empty(&self) -> bool
pub fn set(&mut self, key: EntityKey, field: impl Into<String>, value: Value)
pub fn get(&self, key: &EntityKey, field: &str) -> Option<&Value>
pub fn changes(&self) -> &BTreeMap<EntityKey, Record>
Sourcepub fn clear_entity(&mut self, key: &EntityKey)
pub fn clear_entity(&mut self, key: &EntityKey)
Remove all pending changes for a specific entity key.
Sourcepub fn field_names(&self, key: &EntityKey) -> BTreeSet<String>
pub fn field_names(&self, key: &EntityKey) -> BTreeSet<String>
Get the set of field names that have been modified for a given entity key.