pub struct RawAuditEvent {
pub kind: RawAuditEventKind,
pub entity: String,
pub values: Record,
pub updated_fields: Vec<String>,
pub old_values: Option<Record>,
pub new_values: Option<Record>,
pub changes: Vec<EntityPropertyChange>,
pub trace_chain: Vec<TraceNode>,
}Fields
kind: RawAuditEventKindentity: Stringvalues: Recordupdated_fields: Vec<String>old_values: Option<Record>new_values: Option<Record>changes: Vec<EntityPropertyChange>trace_chain: Vec<TraceNode>Annotation trace chain from the graph save scope chain.
Implementations
Sourceimpl RawAuditEvent
impl RawAuditEvent
pub fn created(entity: impl Into<String>, values: Record) -> Self
pub fn updated(entity: impl Into<String>, values: Record) -> Self
pub fn updated_with_old_values( entity: impl Into<String>, values: Record, old_values: Option<Record>, new_values: Record, updated_fields: Vec<String>, ) -> Self
pub fn deleted( entity: impl Into<String>, id: Value, expected_version: Option<i64>, ) -> Self
pub fn deleted_with_old_values( entity: impl Into<String>, id: Value, expected_version: Option<i64>, old_values: Option<Record>, ) -> Self
pub fn recovered( entity: impl Into<String>, id: Value, expected_version: i64, ) -> Self
pub fn recovered_with_old_values( entity: impl Into<String>, id: Value, expected_version: i64, old_values: Option<Record>, ) -> Self
Sourcepub fn schema_created(
entity: impl Into<String>,
table_name: impl Into<String>,
field_count: usize,
) -> Self
pub fn schema_created( entity: impl Into<String>, table_name: impl Into<String>, field_count: usize, ) -> Self
A new table was created during schema bootstrap.
Sourcepub fn schema_verified(
entity: impl Into<String>,
table_name: impl Into<String>,
field_count: usize,
) -> Self
pub fn schema_verified( entity: impl Into<String>, table_name: impl Into<String>, field_count: usize, ) -> Self
An existing table was verified during schema bootstrap.
Sourcepub fn field_added(
entity: impl Into<String>,
table_name: impl Into<String>,
field_name: impl Into<String>,
) -> Self
pub fn field_added( entity: impl Into<String>, table_name: impl Into<String>, field_name: impl Into<String>, ) -> Self
A new column was added to an existing table (schema migration).
Sourcepub fn data_seeded(
entity: impl Into<String>,
table_name: impl Into<String>,
inserted: usize,
updated: usize,
) -> Self
pub fn data_seeded( entity: impl Into<String>, table_name: impl Into<String>, inserted: usize, updated: usize, ) -> Self
Initial seed data was inserted or updated during bootstrap.
pub fn build_safe_event( &self, audit_mask_fields: &[String], audit_value_max_len: Option<usize>, ) -> SafeAuditEvent