Crate teaql_runtime

Crate teaql_runtime 

Re-exports

pub use entity_save::AuditedSaveExt;
pub use entity_save::DynGraphSaver;
pub use entity_save::GraphSaverFor;
pub use entity_save::graph_node_from_entity;
pub use inmemory_engine::ExprEvaluator;
pub use inmemory_engine::InMemoryQueryEngine;
pub use generated_support::*;

Modules

entity_save
generated_support
inmemory_engine
log_formatter

Macros

module

Structs

BuiltinTranslator
ChangeSetStack
CheckResult
ContextDataService
EntityChangeSet
EntityDataService
EntityKey
EntityPropertyChange
EntityRoot
GraphMutationBatch
GraphMutationPlan
GraphMutationPlanItem
GraphNode
InMemoryAggregationCache
InMemoryCheckerRegistry
InMemoryDataStore
InMemoryEntityDataServiceBehaviorRegistry
InMemoryEntityRegistry
InMemoryMetadataStore
InMemoryRawAuditEventSink
InfoLogEntry
MemoryDataService
ObjectLocation
RawAuditEvent
RelationLoadPlan
RootContext
RuntimeDataService
RuntimeModule
SafeAuditEvent
SafeAuditField
ScopedCommentNode
A stack-allocated scope node forming a parent-pointer cons list.
SnowflakeIdGenerator
SqlLogEntry
SqlLogOptions
TraceScopeToken
A persistent linked-list token for hierarchical trace context.
TypedEntityChecker
Adapter that turns a TypedChecker<T> into a Checker.
UnifiedLogBuffer
UnifiedLogEntry
UserContext

Enums

CheckObjectStatus
CheckRule
ContextError
DataServiceError
EntityAction
Actions that can be applied to an entity to transition its status.
EntityStatus
Tracks the lifecycle status of an entity through a state machine.
GraphMutationKind
GraphOperation
GraphTransactionBoundary
Language
LocationSegment
LogPayload
MemoryDataServiceError
RawAuditEventKind
RuntimeError
SqlLogOperation

Constants

CHECK_OBJECT_STATUS_FIELD

Traits

AggregationCacheBackend
Checker
CheckerRegistry
DataStore
EntityDataServiceBehavior
EntityDataServiceBehaviorRegistry
EntityRegistry
InternalIdGenerator
LedgerEntity
MessageTranslator
MetadataStore
RawAuditEventSink
RequestPolicy
SafeAuditEventSink
SchemaProvider
TypedChecker
Typed version of Checker that works with concrete entity types (T) instead of generic Records.

Functions

clear_record_status
mark_record_status
sorted_update_fields
translate_check_result
translate_location

Type Aliases

CheckResults