Crate teaql_runtime

Crate teaql_runtime 

Modules

log_formatter

Macros

module

Structs

BuiltinTranslator
ChangeSetStack
CheckResult
ContextRepository
EntityChangeSet
EntityKey
EntityPropertyChange
EntityRoot
GraphMutationBatch
GraphMutationPlan
GraphMutationPlanItem
GraphNode
InMemoryAggregationCache
InMemoryCheckerRegistry
InMemoryDataStore
InMemoryMetadataStore
InMemoryRawAuditEventSink
InMemoryRepositoryBehaviorRegistry
InMemoryRepositoryRegistry
InfoLogEntry
MemoryRepository
ObjectLocation
RawAuditEvent
RelationLoadPlan
Repository
ResolvedRepository
RootContext
RuntimeModule
SafeAuditEvent
SafeAuditField
ScopedCommentNode
A stack-allocated scope node forming a parent-pointer cons list.
SnowflakeIdGenerator
SqlLogEntry
SqlLogOptions
TraceScopeToken
A persistent linked-list token for hierarchical trace context.
TypedEntityChecker
Adapter that turns a TypedChecker<T> into a Checker.
UnifiedLogBuffer
UnifiedLogEntry
UserContext

Enums

CheckObjectStatus
CheckRule
ContextError
EntityAction
Actions that can be applied to an entity to transition its status.
EntityStatus
Tracks the lifecycle status of an entity through a state machine.
GraphMutationKind
GraphOperation
GraphTransactionBoundary
Language
LocationSegment
LogPayload
MemoryRepositoryError
RawAuditEventKind
RepositoryError
RuntimeError
SqlLogOperation

Constants

CHECK_OBJECT_STATUS_FIELD

Traits

AggregationCacheBackend
Checker
CheckerRegistry
DataStore
InternalIdGenerator
LedgerEntity
MessageTranslator
MetadataStore
RawAuditEventSink
RepositoryBehavior
RepositoryBehaviorRegistry
RepositoryRegistry
RequestPolicy
SafeAuditEventSink
SchemaProvider
TypedChecker
Typed version of Checker that works with concrete entity types (T) instead of generic Records.

Functions

clear_record_status
mark_record_status
sorted_update_fields
translate_check_result
translate_location

Type Aliases

CheckResults