EntityRoot

Struct EntityRoot 

pub struct EntityRoot { /* private fields */ }

Implementations

Source

impl EntityRoot

pub fn push_change_set(&self)

pub fn pop_change_set(&self) -> Option<EntityChangeSet>

pub fn clear_current_change_set(&self)

pub fn set( &self, key: EntityKey, field: impl Into<String>, value: impl Into<Value>, )

pub fn get(&self, key: &EntityKey, field: &str) -> Option<Value>

pub fn current_change_set(&self) -> EntityChangeSet

pub fn set_comment(&self, comment: impl Into<String>)

Set an annotation comment on this entity root. The comment propagates through the graph save process for observability.

pub fn get_comment(&self) -> Option<String>

Get the annotation comment, if any.

pub fn mark_as_new(&self)

Mark this entity root as a newly created entity in memory.

pub fn is_new(&self) -> bool

Check if this entity root is marked as newly created.

pub fn set_original_record(&self, record: Record)

Store the original record when loaded from DB.

pub fn original_record(&self) -> Option<Record>

Retrieve the original record.

pub fn mark_as_delete(&self, key: EntityKey)

Mark an entity as deleted. The next save() call will treat this entity as a Remove operation in the graph save pipeline. Any pending field changes for this entity are cleared — they are irrelevant when the entity is being deleted.

pub fn is_marked_as_delete(&self, key: &EntityKey) -> bool

Check whether an entity has been marked for deletion.

pub fn changed_field_names(&self, key: &EntityKey) -> BTreeSet<String>

Get the set of field names that have been modified for the given entity key. This is the Rust equivalent of Java’s entity.getUpdatedProperties().