pub struct EntityRoot { /* private fields */ }Implementations
Sourceimpl EntityRoot
impl EntityRoot
pub fn push_change_set(&self)
pub fn pop_change_set(&self) -> Option<EntityChangeSet>
pub fn clear_current_change_set(&self)
pub fn set( &self, key: EntityKey, field: impl Into<String>, value: impl Into<Value>, )
pub fn get(&self, key: &EntityKey, field: &str) -> Option<Value>
pub fn current_change_set(&self) -> EntityChangeSet
Sourcepub fn set_comment(&self, comment: impl Into<String>)
pub fn set_comment(&self, comment: impl Into<String>)
Set an annotation comment on this entity root. The comment propagates through the graph save process for observability.
Sourcepub fn get_comment(&self) -> Option<String>
pub fn get_comment(&self) -> Option<String>
Get the annotation comment, if any.
Sourcepub fn mark_as_delete(&self, key: EntityKey)
pub fn mark_as_delete(&self, key: EntityKey)
Mark an entity as deleted. The next save() call will treat this entity
as a Remove operation in the graph save pipeline.
Any pending field changes for this entity are cleared — they are irrelevant
when the entity is being deleted.
Sourcepub fn is_marked_as_delete(&self, key: &EntityKey) -> bool
pub fn is_marked_as_delete(&self, key: &EntityKey) -> bool
Check whether an entity has been marked for deletion.